table

Function table 

pub fn table<'a, Column, Row, Message, Theme>(
    header: Id,
    body: Id,
    columns: &'a [Column],
    rows: &'a [Row],
    on_sync: fn(AbsoluteOffset) -> Message,
) -> Table<'a, Column, Row, Message, Theme>
where Theme: Catalog + Catalog,
Creates a new Table with the given columns and row data.

header and body are widget::Ids for the header and body scrollables. The body is the only scrollable that the user interacts with directly; the header (and optional footer) are kept in sync through on_sync.

When the body is scrolled, the table emits the on_sync message with the current horizontal offset. You must handle this message in your update function by scrolling the header and footer scrollables to the received offset so they stay aligned with the body.